@@ -15,7 +15,7 @@ use Bio::ToolBox::db_helper qw(
 use Bio::ToolBox::utility qw(simplify_dataset_name sane_chromo_sort);
 use Module::Load;
 
-our $VERSION = '2.01';
+our $VERSION = '2.03';
 
 ### Initialize
 
@@ -752,26 +752,36 @@ sub sort_data {
 
 	# put items into appropriate bins for sorting
 	my @numeric_items;
-	my @mixed_items_end;
 	my @mixed_items;
-	my @asci_items;
 	for my $row_i ( 1 .. $self->last_row ) {
 		my $v = $self->value( $row_i, $index );
-		if ( looks_like_number($v) ) {
+		if ( $v =~ /\d/ && looks_like_number($v) ) {
 			push @numeric_items, [ $v, $row_i ];
 		}
-		elsif ( $v =~ /(\d+)$/x ) {
+		elsif ( $v =~ /^ (\d+) (\D+) (\d+) $/x ) {
+
+			# integer at both ends of string
+			push @mixed_items, [ $1, $2, $3, $row_i ];
+		}
+		elsif ( $v =~ /^ (\d+) (\D.*) $/x ) {
+
+			# integer at beginning of string
+			# use identical integer at the end
+			push @mixed_items, [ $1, $2, 1, $row_i ];
+		}
+		elsif ( $v =~ /^ (.*\D) (\d+) $/x ) {
 
 			# integer at end of string
-			push @mixed_items_end, [ $1, $v, $row_i ];
-		}
-		elsif ( $v =~ /(\d+)/ ) {
-
-			# integer someplace else
-			push @mixed_items, [ $1, $v, $row_i ];
+			# use identical integer at the beginning
+			push @mixed_items, [ 1, $1, $2, $row_i ];
 		}
 		else {
-			push @asci_items, [ $v, $row_i ];
+
+			# no discernable integer in string
+			# we intentionally avoid integers in middle of string cus it's not clear
+			# those should be used in sorting, so just do the string asciibetically
+			# use identical integer at the beginning and end
+			push @mixed_items, [ 1, $v, 1, $row_i ];
 		}
 	}
 
@@ -784,16 +794,9 @@ sub sort_data {
 				sort { $a->[0] <=> $b->[0] } @numeric_items;
 		}
 		if (@mixed_items) {
-			push @new_table, map { $self->{data_table}->[ $_->[2] ] }
-				sort { $a->[0] <=> $b->[0] or $a->[1] cmp $b->[1] } @mixed_items;
-		}
-		if (@mixed_items_end) {
-			push @new_table, map { $self->{data_table}->[ $_->[2] ] }
-				sort { $a->[0] <=> $b->[0] or $a->[1] cmp $b->[1] } @mixed_items_end;
-		}
-		if (@asci_items) {
-			push @new_table, map { $self->{data_table}->[ $_->[1] ] }
-				sort { $a->[0] cmp $b->[0] } @asci_items;
+			push @new_table, map { $self->{data_table}->[ $_->[3] ] }
+				sort { $a->[0] <=> $b->[0] or $a->[1] cmp $b->[1] or $a->[2] <=> $b->[2] }
+				@mixed_items;
 		}
 	}
 	if ( $direction eq 'd' ) {
@@ -802,16 +805,9 @@ sub sort_data {
 				sort { $b->[0] <=> $a->[0] } @numeric_items;
 		}
 		if (@mixed_items) {
-			push @new_table, map { $self->{data_table}->[ $_->[2] ] }
-				sort { $b->[0] <=> $a->[0] or $b->[1] cmp $a->[1] } @mixed_items;
-		}
-		if (@mixed_items_end) {
-			push @new_table, map { $self->{data_table}->[ $_->[2] ] }
-				sort { $b->[0] <=> $a->[0] or $b->[1] cmp $a->[1] } @mixed_items_end;
-		}
-		if (@asci_items) {
-			push @new_table, map { $self->{data_table}->[ $_->[1] ] }
-				sort { $b->[0] cmp $a->[0] } @asci_items;
+			push @new_table, map { $self->{data_table}->[ $_->[3] ] }
+				sort { $b->[0] <=> $a->[0] or $b->[1] cmp $a->[1] or $b->[2] <=> $a->[2] }
+				@mixed_items;
 		}
 	}
 	$self->{data_table} = \@new_table;
@@ -823,25 +819,43 @@ sub gsort_data {
 	my $self = shift;
 
 	# identify indices
-	unless ( $self->feature_type eq 'coordinate' ) {
-		carp 'ERROR: no chromosome and start/position columns to sort!';
-		return;
-	}
 	my $chromo_i = $self->chromo_column;
 	my $start_i  = $self->start_column;
 	my $stop_i   = $self->stop_column || $start_i;
+	my $coord_i  = $self->coord_column;
 
 	# collect the data by chromosome: start and end
 	my %chrom2row;
-	for my $row ( 1 .. $self->last_row ) {
-		my $c = $self->{data_table}->[$row]->[$chromo_i];
-		$chrom2row{$c} ||= [];
-		push @{ $chrom2row{$c} },
-			[
-				$self->{data_table}->[$row]->[$start_i],
-				$self->{data_table}->[$row]->[$stop_i],
-				$self->{data_table}->[$row]
-			];
+	if ( $chromo_i and $start_i ) {
+		for my $row ( 1 .. $self->last_row ) {
+			my $c = $self->{data_table}->[$row]->[$chromo_i];
+			$chrom2row{$c} ||= [];
+			push @{ $chrom2row{$c} },
+				[
+					$self->{data_table}->[$row]->[$start_i],
+					$self->{data_table}->[$row]->[$stop_i],
+					$self->{data_table}->[$row]
+				];
+		}
+	}
+	elsif ($coord_i) {
+		my $dt = $self->{data_table};
+		$self->iterate( sub {
+			my $row = shift;
+			my $c   = $row->seq_id;
+			$chrom2row{$c} ||= [];
+			push @{ $chrom2row{$c} },
+				[
+					$row->start,
+					$row->end || $row->start,
+					$dt->[ $row->row_index ]
+				];
+			
+		} );
+	}
+	else {
+		carp 'ERROR: no chromosome and start/position columns to sort!';
+		return;
 	}
 
 	# get sane chromosome order
@@ -870,7 +884,7 @@ sub gsort_data {
 	return 1;
 }
 
-sub splice_data {
+sub split_data {
 	my ( $self, $part, $total_parts ) = @_;
 
 	unless ( $part and $total_parts ) {
@@ -2055,20 +2069,11 @@ This method is automatically called prior to writing the Data table to file.
   $Data->sort_data($index, 'i'); # increasing sort
 
 This method will sort the Data table by the values in the indicated column.
-Values are automatically sorted based on their value type in the
-following order. Not all types are expected (in most cases only one).
-
-=over 4
-
-=item numeric-only items
-
-=item mixed text with an integer at the end
-
-=item mixed text with an integer anywhere
-
-=item text only
-
-=back
+Sorting is attempted logically by the content and/or sub-content of the
+values, looking for numeric only items (sorted first) and then potentially
+mixed strings with integers at the beginning, end, or both. This should
+smartly handle most scenarios, such as scores, gene names, IDs, or numbered
+items with a prefix or suffix.
 
 Pass the function one or two values. The first value is the index of the
 column upon which the contents are to be sorted. The second (optional) 
@@ -2077,25 +2082,26 @@ c<i> (default) is for increasing sort, and C<d> is for decreasing sort.
 
 =item gsort_data
 
-This method will sort the Data table by increasing genomic coordinates. It 
-requires the presence of chromosome and start (or position) columns, 
-identified by their column names. These are automatically identified. 
-Failure to find these columns mean a failure to sort the table. Chromosome 
-names are sorted in a sane fashion; see L<Bio::ToolBox::utility::sane_chromo_sort>,
-for details. For most tables, features are sorted by increasing start position
-and increasing length, except for GFF-based file formats. These are sorted
-by increasing start position and decreasing length, which is an attempt at
-ensuring parental features occur first in line order over child features to
-improve parsing, avoid orphan features, and maintain tabix compatibility.
+This method will sort the Data table by increasing genomic coordinates. It
+requires the presence of chromosome and start (or position) columns or a
+coordinate string column, identified by their column names. These are
+automatically identified. Failure to find these columns mean a failure to
+sort the table. Chromosome names are sorted in a sane fashion; see
+L<Bio::ToolBox::utility::sane_chromo_sort>, for details. For most tables,
+features are sorted by increasing start position and increasing length,
+except for GFF-based file formats. These are sorted by increasing start
+position and decreasing length, which is an attempt at ensuring parental
+features occur first in line order over child features to improve parsing,
+avoid orphan features, and maintain tabix compatibility.
 
-=item splice_data
+=item split_data
 
 	my $Data = Bio::ToolBox::Data->new(file => $file);
 	my $pm = Parallel::ForkManager->new(4);
 	for my $i (1..4) {
 		$pm->start and next;
 		### in child ###
-		$Data->splice_data($i, 4);
+		$Data->split_data($i, 4);
 		# do something with this portion
 		# then save to a temporary unique file
 		$Data->save("$file_$i");
@@ -2127,7 +2133,7 @@ into the current Data object using the L</reload_children> method.
 Remember that if you fork your script into child processes, any database 
 connections must be re-opened; they are typically not clone safe. If you 
 have an existing database connection by using the L</open_database> method, 
-it should be automatically re-opened for you when you use the L</splice_data> 
+it should be automatically re-opened for you when you use the L</split_data> 
 method, but you will need to call L</open_database> again in the child 
 process to obtain the new database object.
 
