@@ -6,7 +6,7 @@ use Carp;
 use Bio::ToolBox::db_helper::constants;
 require Exporter;
 
-our $VERSION = '2.00';
+our $VERSION = '2.03';
 
 # Exported names
 our @ISA = qw(Exporter);
@@ -40,6 +40,9 @@ our @EXPORT = qw(
 # Lookup hash for caching callback methods
 my %CALLBACKS;
 
+# skip all unwanted flags: SECONDARY,QCFAIL,DUP,SUPPLEMENTARY
+my $UNWANTED_FLAGS = 0xf00;    # 0x100 + 0x200 + 0x400 + 0x800
+
 ### Generate callback subroutine for walking through Bam alignments
 sub assign_callback {
 
@@ -307,9 +310,8 @@ sub assign_callback {
 sub _all_count_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;    # secondary alignment
-	return if $flag & 0x0400;    # marked duplicate
-	return if $flag & 0x0800;    # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $s = $a->pos + 1;
 	my $e = $a->calend;
 	return
@@ -329,9 +331,8 @@ sub _all_count_indexed {
 sub _all_precise_count_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;    # secondary alignment
-	return if $flag & 0x0400;    # marked duplicate
-	return if $flag & 0x0800;    # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $s = $a->pos + 1;
 	return unless ( $s >= $data->{start} and $a->calend <= $data->{stop} );
 	if ( $flag & 0x10 ) {
@@ -347,9 +348,8 @@ sub _all_precise_count_indexed {
 sub _all_name_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;    # secondary alignment
-	return if $flag & 0x0400;    # marked duplicate
-	return if $flag & 0x0800;    # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $s = $a->pos + 1;
 	my $e = $a->calend;
 	return
@@ -376,9 +376,8 @@ sub _all_name_indexed {
 sub _all_count_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;    # secondary alignment
-	return if $flag & 0x0400;    # marked duplicate
-	return if $flag & 0x0800;    # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $s = $a->pos + 1;
 	my $e = $a->calend;
 	return
@@ -390,9 +389,8 @@ sub _all_count_array {
 sub _all_precise_count_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;    # secondary alignment
-	return if $flag & 0x0400;    # marked duplicate
-	return if $flag & 0x0800;    # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	return unless ( $a->pos + 1 >= $data->{start} and $a->calend <= $data->{stop} );
 	push @{ $data->{scores} }, 1;
 }
@@ -400,9 +398,8 @@ sub _all_precise_count_array {
 sub _all_name_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;    # secondary alignment
-	return if $flag & 0x0400;    # marked duplicate
-	return if $flag & 0x0800;    # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $s = $a->pos + 1;
 	my $e = $a->calend;
 	return
@@ -414,9 +411,8 @@ sub _all_name_array {
 sub _forward_count_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed
 	if ( $flag & 0x1 ) {
 
@@ -444,9 +440,8 @@ sub _forward_count_indexed {
 sub _forward_precise_count_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -471,9 +466,8 @@ sub _forward_precise_count_indexed {
 sub _forward_name_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -503,9 +497,8 @@ sub _forward_name_indexed {
 sub _forward_count_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -528,9 +521,8 @@ sub _forward_count_array {
 sub _forward_precise_count_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -549,9 +541,8 @@ sub _forward_precise_count_array {
 sub _forward_name_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -574,9 +565,8 @@ sub _forward_name_array {
 sub _reverse_count_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -604,9 +594,8 @@ sub _reverse_count_indexed {
 sub _reverse_precise_count_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -631,9 +620,8 @@ sub _reverse_precise_count_indexed {
 sub _reverse_name_indexed {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -663,9 +651,8 @@ sub _reverse_name_indexed {
 sub _reverse_count_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -688,9 +675,8 @@ sub _reverse_count_array {
 sub _reverse_precise_count_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
@@ -709,9 +695,8 @@ sub _reverse_precise_count_array {
 sub _reverse_name_array {
 	my ( $a, $data ) = @_;
 	my $flag = $a->flag;
-	return if $flag & 0x0100;       # secondary alignment
-	return if $flag & 0x0400;       # marked duplicate
-	return if $flag & 0x0800;       # supplementary hit
+	return if $flag & $UNWANTED_FLAGS;
+	return if $a->qual < $MAPQ;
 	my $reversed = $flag & 0x10;    # reversed;
 	if ( $flag & 0x1 ) {
 
